
use bevy::{prelude::*, math::bool, render::primitives::Frustum};
use rand::prelude::*;
use bevy::render::primitives::Plane;
enum EyePos {
    Left,
    Right
}

pub struct ScreenInfo {
    name : String,   // main
    width : f32,     // 3.08
    height : f32,    // 2.33
    
    center : Vec3,  // 0.0 -1.15 -3.08
    normal : Vec3,  // 0.0 0.0 1.0
    up: Vec3,       // 0.0 1.0 0.0 (vertical)
    horizontal: Vec3,
   
    top : Vec3,
    bottom : Vec3,
    left : Vec3,
    right : Vec3
}

impl ScreenInfo {


    fn update(&mut self) {
        
        // compute right as up ^ forward
        self.horizontal = self.up.cross(self.normal);

        // points of screen
        self.top = self.center + self.up * (self.height * 0.5);
        self.bottom = self.center - self.up * (self.height * 0.5);
        self.left = self.center - self.horizontal * (self.height * 0.5);
        self.right = self.center + self.horizontal * (self.height * 0.5);
        
    }

    fn intersection(
        &self,
        p1: Vec3,
        p2: Vec3) -> (bool,Vec3)
    {

        let u = self.normal.dot(self.center - p1) / self.normal.dot(p2 - p1);

        let intersection_point = p1 + ((p2 - p1) * u);

        (u >= 0.0 && u <= 1.0,intersection_point)
    }


    fn normal_intersection(&self,
        p1: Vec3) -> (bool,Vec3)
    {
        let p2 = p1 - self.normal * 10.0;
        
        self.intersection(p1, p2)
    }

    
}
